CA17-Cl02
open | /cms/logout |
open | /admin/ |
type | id_username | admin
type | id_password | admin
clickAndWait | //input[@value='Iniciar sesión'] |
clickAndWait | link=Photos |
clickAndWait | link=Añadir foto |
type | id_name | CA17-Cl02 photo
select | id_status | label=Publicado
type | id_image | C:\Documents and Settings\mrivera\Escritorio\Merengue\test-data\test_image.jpg
clickAndWait | _save |
verifyTextPresent | CA17-Cl02 photo (test_image.jpg) |
verifyTextPresent | Publicado |
clickAndWait | link=CA17-Cl02 photo (test_image.jpg) |
select | id_status | label=Borrador
clickAndWait | _save |
verifyTextPresent | CA17-Cl02 photo (test_image.jpg) |
verifyTextPresent | Borrador |
clickAndWait | link=CA17-Cl02 photo (test_image.jpg) |
select | id_status | label=Pendiente
clickAndWait | _save |
verifyTextPresent | CA17-Cl02 photo (test_image.jpg) |
verifyTextPresent | Pendiente |
clickAndWait | link=CA17-Cl02 photo (test_image.jpg) |
clickAndWait | link=Borrar |
clickAndWait | //input[@value='Sí, estoy seguro'] |
clickAndWait | link=Terminar sesión |